"""
This type stub file was generated by pyright.
"""

from enum import Enum
from enum import unique
from typing import Any

def checkbox(checked: bool) -> str:
    ...

@unique
class MenuButton(Enum):
    """Non-composable menu action enum."""
    ADD = ...
    BACK = ...
    EDIT = ...
    EXIT = ...
    MENU = ...
    METADATA = ...
    OK = ...
    OPTIONS = ...
    PROMPT = ...
    REMOVE = ...
    RESET = ...
    YES = ...
    NO = ...
    SKIP = ...

    @property
    def _tuple(self: MenuButton) -> tuple[str, int]: ...

    @property
    def _str(self: MenuButton) -> str: ...



"""
This type stub file was generated by pyright.
"""

from argparse import Action
from argparse import ArgumentParser
from argparse import Namespace
from collections.abc import Sequence
from dataclasses import dataclass
from typing import TYPE_CHECKING
from typing import Any
from typing import Collection
from typing import NoReturn

from packaging.version import Version

"""Parsing actions for the OZI commandline interface."""
if TYPE_CHECKING:
    ...
_prefix = ...
@dataclass
class ExactMatch:
    """Exact matches data for packaging core metadata."""
    audience: tuple[str, ...] = ...
    language: tuple[str, ...] = ...
    framework: tuple[str, ...] = ...
    environment: tuple[str, ...] = ...
    license: tuple[str, ...] = ...
    license_id: tuple[str, ...] = ...
    license_exception_id: tuple[str, ...] = ...
    status: tuple[str, ...] = ...
    topic: tuple[str, ...] = ...


class CloseMatch(Action):
    """Special argparse choices action. Warn the user if a close match could not be found."""
    exact_match = ...
    def __init__(self, option_strings: list[str], dest: str, nargs: int | str | None = ..., **kwargs: Any) -> None:
        """Argparse init"""
        ...
    
    def close_matches(self, key: str, value: str) -> Sequence[str]:
        """Get a close matches for a Python project packaging core metadata key.

        :param key: Python project packaging core metadata key name (normalized)
        :type key: str
        :param value: the value to query a close match for
        :type value: Sequence[str]
        :return: sequence with the best match or an empty sequence
        :rtype: Sequence[str]
        """
        ...
    
    def __call__(self, parser: ArgumentParser, namespace: Namespace, values: str | Sequence[str] | None, option_string: str | None = ...) -> None:
        """Find closest matching class attribute."""
        ...
    


def check_for_update(current_version: Version, releases: Collection[Version]) -> None:
    """Issue a warning if installed version of OZI is not up to date."""
    ...

def check_version(version: str) -> NoReturn:
    """Check for a newer version of OZI and exit."""
    ...

def info(version: str) -> NoReturn:
    """Print all metadata as JSON and exit."""
    ...

def list_available(key: str) -> NoReturn:
    """Print a list of valid values for a key and exit."""
    ...

def license_expression(expr: str) -> NoReturn:
    """Validate a SPDX license expression."""
    ...




"""
This type stub file was generated by pyright.
"""

from dataclasses import dataclass
from functools import lru_cache
from typing import TYPE_CHECKING

"""Trove packaging classifiers interface."""
if TYPE_CHECKING:
    ...
@lru_cache
def get_trove_prefix(text: str) -> str | None:
    """Get a trove classifier prefix from a classifier string.

    :param text: full classifier text
    :type text: str
    :return: the prefix if the classifier text is valid otherwise None
    :rtype: str | None
    """
    ...

valid_trove_prefixes = ...
@dataclass(frozen=True, slots=True, eq=True)
class Prefix:
    """Trove :term:`classifier` prefix literals for :term:`PyPI`"""
    audience: str = 'Intended Audience :: '
    environment: str = 'Environment :: '
    framework: str = 'Framework :: '
    language: str = 'Natural Language :: '
    license: str = 'License :: '
    status: str = 'Development Status :: '
    topic: str = 'Topic :: '
    def __post_init__(self) -> None:
        """Check if any of the default attributes are deprecated upstream."""
        ...
    


@lru_cache
def from_prefix(prefix: str) -> tuple[str, ...]:
    """Return all matching classifiers for a prefix string."""
    ...




# This file was generated by ozi_core.generate_locales DO NOT EDIT
data: dict[str, dict[str, str | None] | dict[str, str]] = {
'en': {'adm-confirm': 'Confirm project creation?\n'
                       'PKG-INFO Metadata:\n',
        'adm-disclaimer-text': 'The information provided on this '
                               'prompt does not, and is not intended '
                               'to, constitute legal advice. All '
                               'information, content, and materials '
                               'available on this prompt are for '
                               'general informational purposes only. '
                               'Information on this prompt may not '
                               'constitute the most up-to-date legal '
                               'or other information.\n'
                               '\n'
                               'THE LICENSE TEMPLATES, LICENSE '
                               'IDENTIFIERS, LICENSE CLASSIFIERS, AND '
                               'LICENSE EXPRESSION PARSING SERVICES, '
                               'AND ALL OTHER CONTENTS ARE PROVIDED '
                               '"AS IS", NO REPRESENTATIONS ARE MADE '
                               'THAT THE CONTENT IS ERROR-FREE AND/OR '
                               'APPLICABLE FOR ANY PURPOSE, INCLUDING '
                               'MERCHANTABILITY.\n'
                               '\n'
                               'Readers of this prompt should contact '
                               'their attorney to obtain advice with '
                               'respect to any particular legal '
                               'matter. The OZI Project is not a law '
                               'firm and does not provide legal '
                               'advice. No reader or user of this '
                               'prompt should act or abstain from '
                               'acting on the basis of information on '
                               'this prompt without first seeking '
                               'legal advice from counsel in the '
                               'relevant jurisdiction. Legal counsel '
                               'can ensure that the information '
                               'provided in this prompt is applicable '
                               'to your particular situation. Use of, '
                               'or reading, this prompt or any of the '
                               'resources contained within does not '
                               'create an attorney-client '
                               'relationship.\n',
        'adm-disclaimer-title': 'Disclaimer',
        'adm-maintainers': 'Are there any maintainers of '
                           '$project_name?\n'
                           '(other than the author or authors)\n',
        'adm-metadata': 'PKG-INFO Metadata:',
        'btn-back': '← Back',
        'btn-edit': '✎ Edit',
        'btn-exit': '✘ Exit',
        'btn-menu': '☰  Menu',
        'btn-metadata': '∋ Metadata',
        'btn-no': 'No',
        'btn-ok': '✔ Ok',
        'btn-options': '⚙ Options',
        'btn-prompt': '⌂ Prompt',
        'btn-reset': '↺ Reset',
        'btn-skip': '⇒ Skip',
        'btn-yes': 'Yes',
        'new-dlg-title': 'ozi-new interactive prompt',
        'edit-menu-btn-audience': 'Intended Audience',
        'edit-menu-btn-author': 'Author',
        'edit-menu-btn-email': 'Author-email',
        'edit-menu-btn-environment': 'Environment',
        'edit-menu-btn-framework': 'Framework',
        'edit-menu-btn-homepage': 'Home-page',
        'edit-menu-btn-keywords': 'Keywords',
        'edit-menu-btn-language': 'Natural Language',
        'edit-menu-btn-license': 'License',
        'edit-menu-btn-license-expression': 'License-Expression',
        'edit-menu-btn-license-file': 'License-File',
        'edit-menu-btn-maintainer': 'Maintainer',
        'edit-menu-btn-maintainer-email': 'Maintainer-email',
        'edit-menu-btn-name': 'Name',
        'edit-menu-btn-project-url': 'Project-URL',
        'edit-menu-btn-readme-type': 'Description-Content-Type',
        'edit-menu-btn-requires-dist': 'Requires-Dist (requirements)',
        'edit-menu-btn-status': 'Status',
        'edit-menu-btn-summary': 'Summary',
        'edit-menu-btn-topic': 'Topic',
        'edit-menu-btn-typing': 'Typing',
        'edit-menu-text': 'Edit menu, select content to edit:',
        'err-name-exists': 'project with that name exists.',
        'err-name-invalid': 'invalid project name.',
        'err-new-version': 'A newer version of OZI ($latest > '
                           '$currentversion), available for download '
                           'on PyPI',
        'err-no-close-match': 'There is no available $key option '
                              'matching "$value".\n'
                              'List available options:\n',
        'err-no-empty': 'cannot not be empty.',
        'err-pkg-not-found': 'package not found.',
        'err-too-long': 'input is too long.',
        'err-version-check': 'OZI package version check failed with '
                             'status code $status',
        'lang-en': 'English',
        'lang-zh': '简体中文 Chinese (Simplified)',
        'main-menu-text': 'Main menu, select an action:',
        'main-menu-yn-exit': 'Exit the prompt?',
        'main-menu-yn-reset': 'Reset prompt and start over?',
        'msg-input-invalid': 'Invalid input "$value"\n'
                             '$errmsg\n'
                             'Press ENTER to continue.\n',
        'opt-menu-allow-file': 'Allow File Patterns ...',
        'opt-menu-allow-file-input': 'Edit allowed existing files:',
        'opt-menu-ci-provider': 'CI Provider ...',
        'opt-menu-ci-provider-input': 'Change continuous integration '
                                      'providers:',
        'opt-menu-copyright-head': 'Copyright Header ...',
        'opt-menu-copyright-head-input': 'Edit copyright header:',
        'opt-menu-enable-cython': 'Enable Cython: $value',
        'opt-menu-enable-uv': 'Enable uv: $value',
        'opt-menu-github-harden-runner': 'Hardened GitHub CI/CD: '
                                         '$value',
        'opt-menu-language': 'Interface Language: $value',
        'opt-menu-language-text': 'Select the user interface language:',
        'opt-menu-strict': 'Strict Mode: $value',
        'opt-menu-title': 'Options menu, select an option:',
        'opt-menu-verify-email': 'Verify Email: $value',
        'pro-author': 'Who is the author or authors of $projectname?\n'
                      '(comma-separated list)\n',
        'pro-author-email': 'What are the email addresses of the '
                            'author or authors of $projectname?\n'
                            '(comma-separated list)\n',
        'pro-classifier-cbl': 'Please select $key classifier or '
                              'classifiers:',
        'pro-homepage': 'What is the home-page URL for $projectname?',
        'pro-keywords': 'What are some keywords used to describe '
                        '$projectname?\n'
                        '(comma-separated list)\n',
        'pro-license': 'Please select a license classifier for '
                       '$projectname',
        'pro-license-expression-input': 'License: $license\n'
                                        'Edit SPDX license expression '
                                        'for $projectname:\n',
        'pro-license-expression-radio': 'License: $license\n'
                                        'Please select a SPDX '
                                        'license-id for '
                                        '$projectname:\n',
        'pro-license-file': 'Select a license file name for '
                            '$projectname',
        'pro-maintainer': 'What is the maintainer or maintainers name '
                          'of $projectname?\n'
                          '(comma-separated list)\n',
        'pro-maintainer-email': 'What are the email addresses of the '
                                'maintainer or maintainers of '
                                '$projectname?\n'
                                '(comma-separated list)\n',
        'pro-name': 'What is the name of the project?\n'
                    '(PyPI package name: no spaces, alphanumeric '
                    'words, ".-_" as delimiters)\n',
        'pro-project-urls-cbl': 'Please select project URLs you want '
                                'to add to $projectname:',
        'pro-project-urls-cbl-bug-report': 'Bug Report',
        'pro-project-urls-cbl-changelog': 'Changelog',
        'pro-project-urls-cbl-documentation': 'Documentation',
        'pro-project-urls-cbl-funding': 'Funding',
        'pro-project-urls-cbl-source': 'Source',
        'pro-project-urls-input': 'Please enter the $urltype URL for '
                                  '$projectname:',
        'pro-readme-type': 'Please select README type for '
                           '$projectname:',
        'pro-readme-type-radio-md': 'Markdown',
        'pro-readme-type-radio-rst': 'reStructuredText',
        'pro-readme-type-radio-txt': 'Plaintext',
        'pro-requires-dist': 'Add or remove dependency requirements to '
                             '$projectname',
        'pro-requires-dist-add': 'Add',
        'pro-requires-dist-cbl-remove': 'Select packages to delete:',
        'pro-requires-dist-msg-remove-no-requirements': 'No '
                                                        'requirements '
                                                        'to remove.',
        'pro-requires-dist-remove': 'Remove',
        'pro-requires-dist-search': 'Search PyPI packages:',
        'pro-summary': 'What does the project, $projectname, do?\n'
                       '(a short summary 1-2 sentences)\n',
        'pro-typing': 'Please select typing classifier for '
                      '$projectname:',
        'pro-typing-radio-stubs-only': 'Stubs Only',
        'pro-typing-radio-typed': 'Typed',
        'term-choices': 'choices',
        'term-ci-provider': 'continuous integration and release '
                            'provider',
        'term-classifier': 'Classifier',
        'term-comment-diagnostic': 'comment diagnostic',
        'term-continuous-integration-checkpoints': 'continuous '
                                                   'integration '
                                                   'checkpoints',
        'term-copyright-head': 'copyright header string',
        'term-custom': 'custom',
        'term-default-metadata': 'default metadata',
        'term-defaults': 'defaults',
        'term-desc-new-interactive': 'Create a new Python project with '
                                     'OZI using the interactive '
                                     'prompt.',
        'term-desc-new-project': 'Create a new Python project with '
                                 'OZI.',
        'term-found': 'found',
        'term-help': '$name ($text)',
        'term-help-allow-file': 'In the new project target folder',
        'term-help-audience': 'use zero or more times',
        'term-help-author': 'use zero or more times, single output',
        'term-help-author-email': 'use zero or more times, single '
                                  'output',
        'term-help-check-package-exists': 'check if the package name '
                                          'exists on PyPI, default: '
                                          'yes',
        'term-help-check-version': 'Check for a newer version of OZI '
                                   'and exit.',
        'term-help-default': '$name ($text) defaults to: $default',
        'term-help-enable-cython': 'use Cython to build Python '
                                   'extension modules. default: no',
        'term-help-enable-uv': 'Use uv to compile and install Python '
                               'requirements, default: no',
        'term-help-environment': 'use zero or more times',
        'term-help-fix': 'show help for the ozi-fix command',
        'term-help-fix-add': 'add files or directories to a project',
        'term-help-fix-missing': 'Check your OZI project for missing '
                                 'files.',
        'term-help-fix-remove': 'remove files or directories from a '
                                'project',
        'term-help-fix-source': 'Create a new Python source in an OZI '
                                'project.',
        'term-help-fix-target': 'target OZI project directory',
        'term-help-fix-test': 'Create a new Python test in an OZI '
                              'project.',
        'term-help-framework': 'use zero or more times',
        'term-help-github-harden-runner': 'add a harden runner to all '
                                          'non-reusable workflow jobs, '
                                          'default: no',
        'term-help-help': 'show this help message and exit',
        'term-help-homepage': 'use once',
        'term-help-info': 'Print all metadata as JSON and exit.',
        'term-help-keywords': 'use once, comma-delimited list',
        'term-help-language': 'use zero or more times',
        'term-help-license': 'use once',
        'term-help-license-expression': 'use once, SPDX license '
                                        'expression',
        'term-help-license-file': 'use once',
        'term-help-list-available': 'Print a list of valid values for '
                                    'a key and exit.',
        'term-help-maintainer': 'use zero or more times, single output '
                                '(if different from author)',
        'term-help-maintainer-email': 'use zero or more times, single '
                                      'output (if different from '
                                      'author email)',
        'term-help-name': 'use once',
        'term-help-name-allow-file': 'Add file patterns to be ignored',
        'term-help-new': 'show help for the ozi-new command',
        'term-help-new-interactive': 'create a new Python project '
                                     'using the interactive prompt',
        'term-help-new-project': 'create a new Python project with OZI',
        'term-help-new-target': 'directory path for new project '
                                '(default: current working directory)',
        'term-help-pretty': 'output indented JSON, default: no',
        'term-help-project-url': 'use zero or more times, '
                                 'comma-separated tuples (name, url)',
        'term-help-requires-dist': 'use zero or more times',
        'term-help-status': 'use zero or more times',
        'term-help-strict': 'strict mode raises warnings to errors, '
                            'default: no',
        'term-help-summary': 'use once',
        'term-help-topic': 'use zero or more times',
        'term-help-typing': 'use zero or more times',
        'term-help-valid-license-expression': 'Validate a SPDX license '
                                              'expression.',
        'term-help-verify-email': 'verify deliverability of email '
                                  'domain, default: no',
        'term-help-version': 'Print the current version and exit.',
        'term-missing': 'missing',
        'term-optional-metadata': 'optional metadata',
        'term-options': 'options',
        'term-output': 'output',
        'term-parsing-success': 'parsed successfully',
        'term-positional-args': 'positional arguments',
        'term-project-authoring-console-app': 'project authoring '
                                              'console app',
        'term-project-maintenance-console-app': 'project maintenance '
                                                'console app',
        'term-required': 'required',
        'term-required-metadata': 'required metadata',
        'term-score': 'score',
        'term-see-ref': 'See',
        'term-spdx-license-expression': None,
        'term-subdir': 'subdir',
        'term-tap-ambiguous-license': 'ambiguous license, set '
                                      '--license-expression to one '
                                      'based on the following:\n',
        'term-tap-ambiguous-pep639': 'ambiguous per PEP-639',
        'term-tap-dev-version': 'The OZI package is a development '
                                'version',
        'term-tap-empty-netloc': 'URL netloc blank',
        'term-tap-first-license': 'Multiple licenses match, only the '
                                  'first one is selected',
        'term-tap-header-license-file-not-found': 'license file name '
                                                  'not found',
        'term-tap-header-name-not-found': 'project name not found',
        'term-tap-https-only': 'only https:// URL scheme is supported',
        'term-tap-identical-author': 'the Author and Maintainer are '
                                     'the same',
        'term-tap-identical-email': 'one or more Author-email and '
                                    'Maintainer-email are the same',
        'term-tap-invalid-ci-provider': '--ci-provider $ciprovider '
                                        'unrecognized. user will not '
                                        'be set.',
        'term-tap-leave-blank': '$key should be left blank',
        'term-tap-meson-build-license-array': 'An array of licenses is '
                                              'found in meson.build, '
                                              'OZI will only use the '
                                              'first one.',
        'term-tap-name-gt32': '>32 character limit\n',
        'term-tap-netloc': 'URL netloc',
        'term-tap-not-set': '$key is not set',
        'term-tap-summary-gt512': '>512 character limit\n',
        'term-tap-target-not-empty': 'the directory is not empty and '
                                     'no files will be created',
        'term-tap-unsupported-url-scheme': 'URL scheme unsupported',
        'term-tap-up-to-date': 'The OZI package has been updated',
        'term-tap-url-scheme': 'URL scheme',
        'term-tap-user-template-not-found': 'User template not found',
        'term-tox-e-dist': 'run distribution and packaging',
        'term-tox-e-lint': 'run formatting, static analysis, and type '
                           'checking',
        'term-tox-e-test': 'run tests and coverage',
        'term-warn-remove-dir': 'Cannot delete a non-empty or '
                                'non-existent $key: "$child"\n'},
 'zh': {'adm-confirm': '确认创建项目？元数据：',
        'adm-disclaimer-text': '本警报中提供的信息不构成法律建议，也不旨在构成法律建议。 '
                               '本警报中的所有信息、内容和材料仅供一般参考。 '
                               '本警报中的信息，无论是否合法，可能不是最新的。\n'
                               '\n'
                               '许可证模板、许可证标识符、许可证分类器和许可证表达式解析服务以及所有其他 '
                               '均按『原样』提供，不保证内容 无错误和/或适用于任何目的，包括适销性。 '
                               '本警报的读者应联系他们的律师以获取有关任何特定法律问题的建议。\n'
                               '\n'
                               'ＯＺＩ项目不是律师事务所，不提供法律建议。 '
                               '任何读者或用户都不得根据本警报中的信息采取行动或不采取行动， '
                               '除非事先寻求具有相关管辖权的律师的法律建议。 '
                               '法律顾问可以确保本警报中提供的信息适合您的特定情况。 '
                               '使用或阅读本警报或其中包含的任何资源不会建立律师-客户关系。\n',
        'adm-disclaimer-title': '免責聲明',
        'adm-maintainers': '除了作者之外，『$project_name』还有其他维护者吗？',
        'adm-metadata': '元数据：',
        'btn-back': '返回',
        'btn-edit': '编辑',
        'btn-exit': '退出',
        'btn-menu': '選單',
        'btn-metadata': '查看元数据',
        'btn-no': '不',
        'btn-ok': '好的',
        'btn-options': '更改选项',
        'btn-prompt': '提示符',
        'btn-reset': '重置',
        'btn-skip': '跳过',
        'btn-yes': '是的',
        'new-dlg-title': 'ｏｚｉ－ｎｅｗ 互 動 提 示 符',
        'edit-menu-btn-audience': '目标受众（Ｉｎｔｅｎｄｅｄ\u3000Ａｕｄｉｅｎｃｅ）',
        'edit-menu-btn-author': '作者（Ａｕｔｈｏｒ）',
        'edit-menu-btn-email': '电子邮件（Ａｕｔｈｏｒ－ｅｍａｉｌ）',
        'edit-menu-btn-environment': '环境（Ｅｎｖｉｒｏｎｍｅｎｔ）',
        'edit-menu-btn-framework': '框架（Ｆｒａｍｅｗｏｒｋ）',
        'edit-menu-btn-homepage': '头版（Ｈｏｍｅ－ｐａｇｅ）',
        'edit-menu-btn-keywords': '关键字（Ｋｅｙｗｏｒｄｓ）',
        'edit-menu-btn-language': '自然语言（Ｎａｔｕｒａｌ\u3000Ｌａｎｇｕａｇｅ）',
        'edit-menu-btn-license': '软体许可（Ｌｉｃｅｎｓｅ）',
        'edit-menu-btn-license-expression': '软体许可表达式（Ｌｉｃｅｎｓｅ－Ｅｘｐｒｅｓｓｉｏｎ）',
        'edit-menu-btn-license-file': '许可证文件（Ｌｉｃｅｎｓｅ－Ｆｉｌｅ）',
        'edit-menu-btn-maintainer': '维护者（Ｍａｉｎｔａｉｎｅｒ）',
        'edit-menu-btn-maintainer-email': '维护者电子邮件（Ｍａｉｎｔａｉｎｅｒ－ｅｍａｉｌ）',
        'edit-menu-btn-name': '姓名（Ｎａｍｅ）',
        'edit-menu-btn-project-url': '专案网址（Ｐｒｏｊｅｃｔ－ＵＲＬ）',
        'edit-menu-btn-readme-type': '自述文件内容类型（Ｄｅｓｃｒｉｐｔｉｏｎ－Ｃｏｎｔｅｎｔ－Ｔｙｐｅ）',
        'edit-menu-btn-requires-dist': '要求（Ｒｅｑｕｉｒｅｓ－Ｄｉｓｔ）',
        'edit-menu-btn-status': '地位（Ｓｔａｔｕｓ）',
        'edit-menu-btn-summary': '概括（Ｓｕｍｍａｒｙ）',
        'edit-menu-btn-topic': '话题（Ｔｏｐｉｃ）',
        'edit-menu-btn-typing': '类型（Ｔｙｐｉｎｇ）',
        'edit-menu-text': '编辑选单，选择要编辑的内容：',
        'err-name-exists': '同名的项目已存在。',
        'err-name-invalid': '项目名称无效。',
        'err-new-version': '较新版本的ＯＺＩ（$latest＞$currentversion），可在ＰｙＰＩ上下载',
        'err-no-close-match': '没有与『$value』匹配的可用$key选项。\n列出可用选项：\n',
        'err-no-empty': '不能为空。',
        'err-pkg-not-found': '找不到包包。',
        'err-too-long': '输入太长。',
        'err-version-check': 'ＯＺＩ软件包版本检查失败，状态代码为：$status',
        'lang-en': '英语（Ｅｎｇｌｉｓｈ）',
        'lang-zh': '简体中文',
        'main-menu-text': '選單，选择动作：',
        'main-menu-yn-exit': '退出提示符？',
        'main-menu-yn-reset': '重置提示并重新开始？',
        'msg-input-invalid': '输入无效：$value\n$errmsg\n按『↵』持续\n',
        'opt-menu-allow-file': '允许的归档正规表示式⋯⋯',
        'opt-menu-allow-file-input': '编辑允许的存档正规表示式：',
        'opt-menu-ci-provider': '持续整合提供者⋯⋯',
        'opt-menu-ci-provider-input': '更换持续整合提供者：',
        'opt-menu-copyright-head': '版权文件头⋯⋯',
        'opt-menu-copyright-head-input': '编辑版权文件头：',
        'opt-menu-enable-cython': '允许Ｃｙｔｈｏｎ：$value',
        'opt-menu-enable-uv': '允许ｕｖ：$value',
        'opt-menu-github-harden-runner': '安全的ＧｉｔＨｕｂ持续整合和分发：$value',
        'opt-menu-language': '界面语言：$value',
        'opt-menu-language-text': '选择用户界面语言',
        'opt-menu-strict': '严格模式：$value',
        'opt-menu-title': '选项选单，选择一个选项：',
        'opt-menu-verify-email': '验证电子邮件：$value',
        'pro-author': '『$projectname』的作者是谁？\n（分隔列表）\n',
        'pro-author-email': '作者的电子邮件地址是『$projectname』？\n（分隔列表）\n',
        'pro-classifier-cbl': '请选择『$key』分类器：',
        'pro-homepage': '『$projectname』的主页ＵＲＬ是什么？',
        'pro-keywords': '用来描述『$projectname』的关键字是什么？\n（分隔列表）\n',
        'pro-license': '请为『$projectname』选择许可证分类器。',
        'pro-license-expression-input': '许可：$license\n'
                                        '编辑『$projectname』的ＳＰＤＸ许可证表达式：\n',
        'pro-license-expression-radio': '许可：$license\n'
                                        '请为『$projectname』选择ＳＰＤＸ许可证ＩＤ：\n',
        'pro-license-file': '为『$projectname』选择许可证文件名',
        'pro-maintainer': '谁是『$projectname』的维护者？\n（分隔列表）\n',
        'pro-maintainer-email': '『$projectname』维护者的电子邮件地址是什么\n（分隔列表）\n',
        'pro-name': '项目名称是什么？\n（ＰｙＰＩ套件名称：无空格、字母数字字元、『._-』作为分隔符）\n',
        'pro-project-urls-cbl': '请选择您要新增至『$projectname』的专案ＵＲＬ：',
        'pro-project-urls-cbl-bug-report': '错误报告（Ｂｕｇ\u3000Ｒｅｐｏｒｔ）',
        'pro-project-urls-cbl-changelog': '变更日志（Ｃｈａｎｇｅｌｏｇ）',
        'pro-project-urls-cbl-documentation': '文件（Ｄｏｃｕｍｅｎｔａｔｉｏｎ）',
        'pro-project-urls-cbl-funding': '资金（Ｆｕｎｄｉｎｇ）',
        'pro-project-urls-cbl-source': '原始码（Ｓｏｕｒｃｅ）',
        'pro-project-urls-input': '请输入『$projectname』的$urltypeＵＲＬ：',
        'pro-readme-type': '请为『$projectname』选择自述文件类型：',
        'pro-readme-type-radio-md': '轻量级标记语言Ｍａｒｋｄｏｗｎ',
        'pro-readme-type-radio-rst': '轻量级标记语言ｒｅＳｔｒｕｃｔｕｒｅｄＴｅｘｔ',
        'pro-readme-type-radio-txt': '纯文本',
        'pro-requires-dist': '新增或删除对『$projectname』的依赖关系要求。',
        'pro-requires-dist-add': '新增',
        'pro-requires-dist-cbl-remove': '选择要删除的包：',
        'pro-requires-dist-msg-remove-no-requirements': '没有删除请求。',
        'pro-requires-dist-remove': '删除',
        'pro-requires-dist-search': '搜寻ＰｙＰＩ包：',
        'pro-summary': '项目『$projectname』是做什么的？\n（简短摘要 1〜2 句话）\n',
        'pro-typing': '请为『$projectname』选择一个类型存根分类器：',
        'pro-typing-radio-stubs-only': '仅限类型检查存根（Ｓｔｕｂｓ\u3000Ｏｎｌｙ）',
        'pro-typing-radio-typed': '类型检查（Ｔｙｐｅｄ）',
        'term-choices': '选择',
        'term-ci-provider': '持续集成和发布提供商',
        'term-classifier': '分类器',
        'term-comment-diagnostic': '评论诊断',
        'term-continuous-integration-checkpoints': '持续集成检查点',
        'term-copyright-head': '版权标题字符串',
        'term-custom': '定制',
        'term-default-metadata': '默认元数据',
        'term-defaults': '默认值',
        'term-desc-new-interactive': '使用交互式提示通过ＯＺＩ创建一个新的Ｐｙｔｈｏｎ项目。',
        'term-desc-new-project': '使用ＯＺＩ创建一个新的Ｐｙｔｈｏｎ项目',
        'term-found': '成立',
        'term-help': '$name（$text）',
        'term-help-allow-file': '在新项目目标文件夹中',
        'term-help-audience': '使用零次或多次',
        'term-help-author': '使用零次或多次，单次输出',
        'term-help-author-email': '使用零次或多次，单次输出',
        'term-help-check-package-exists': '检查ＰｙＰＩ上是否存在包名称，默认：是',
        'term-help-check-version': '检查ＯＺＩ的较新版本并退出。',
        'term-help-default': '$name（$text）默认设置：$default',
        'term-help-enable-cython': '使用Ｃｙｔｈｏｎ构建Ｐｙｔｈｏｎ扩展模块。默认值：否',
        'term-help-enable-uv': '使用ｕｖ编译并安装Ｐｙｔｈｏｎ要求，默认：否',
        'term-help-environment': '使用零次或多次',
        'term-help-fix': '显示ozi-fix命令的帮助',
        'term-help-fix-add': '向项目添加文件或目录',
        'term-help-fix-missing': '检查您的ＯＺＩ项目是否缺少文件。',
        'term-help-fix-remove': '从项目中删除文件或目录',
        'term-help-fix-source': '在ＯＺＩ项目中创建一个新的Ｐｙｔｈｏｎ源。',
        'term-help-fix-target': '目标ＯＺＩ项目目录',
        'term-help-fix-test': '在ＯＺＩ项目中创建一个新的Ｐｙｔｈｏｎ测试。',
        'term-help-framework': '使用零次或多次',
        'term-help-github-harden-runner': '保护所有不可重复使用的工作流作业，默认值：否',
        'term-help-help': '显示此帮助消息并退出',
        'term-help-homepage': '使用一次',
        'term-help-info': '将所有元数据打印为ＪＳＯＮ并退出。',
        'term-help-keywords': '使用一次，逗号分隔列表',
        'term-help-language': '使用零次或多次',
        'term-help-license': '使用一次',
        'term-help-license-expression': '使用一次，ＳＰＤＸ许可表达',
        'term-help-license-file': '使用一次',
        'term-help-list-available': '打印某个键的有效值列表并退出。',
        'term-help-maintainer': '使用零次或多次，单一输出（如果与作者不同）',
        'term-help-maintainer-email': '使用零次或多次，单一输出（如果与作者电子邮件不同）',
        'term-help-name': '使用一次',
        'term-help-name-allow-file': '添加要忽略的文件模式',
        'term-help-new': '显示ozi-new命令的帮助',
        'term-help-new-interactive': '使用交互式提示创建一个新的Ｐｙｔｈｏｎ项目',
        'term-help-new-project': '使用ＯＺＩ创建一个新的Ｐｙｔｈｏｎ项目',
        'term-help-new-target': '新项目的目录路径（默认：当前工作目录）',
        'term-help-pretty': '输出缩进的ＪＳＯＮ，默认：否',
        'term-help-project-url': '使用零次或多次，逗号分隔的元组（名称、网址）',
        'term-help-requires-dist': '使用零次或多次',
        'term-help-status': '使用零次或多次',
        'term-help-strict': '严格模式会对错误发出警告，默认值：否',
        'term-help-summary': '使用一次',
        'term-help-topic': '使用零次或多次',
        'term-help-typing': '使用零次或多次',
        'term-help-valid-license-expression': '验证ＳＰＤＸ许可证表达式。',
        'term-help-verify-email': '验证电子邮件域的可传递性，默认：否',
        'term-help-version': '打印当前版本并退出。',
        'term-missing': '丢失的',
        'term-optional-metadata': '可选元数据',
        'term-options': '选项',
        'term-output': '输出',
        'term-parsing-success': '解析成功',
        'term-positional-args': '位置参数',
        'term-project-authoring-console-app': '项目创作控制台应用程序',
        'term-project-maintenance-console-app': '项目维护控制台应用程序',
        'term-required': '需要',
        'term-required-metadata': '必需元数据',
        'term-score': '比分',
        'term-see-ref': '参见参考：',
        'term-spdx-license-expression': '（ＳＰＤＸ许可证表达式）',
        'term-subdir': '子目錄',
        'term-tap-ambiguous-license': '如果许可证不明确，请将『--license-expression』设置为基于以下内容的许可证：',
        'term-tap-ambiguous-pep639': '根据ＰＥＰ－６３９存在歧义',
        'term-tap-dev-version': 'ＯＺＩ软件包是开发版本',
        'term-tap-empty-netloc': 'ＵＲＬ网络位置为空',
        'term-tap-first-license': '多个许可证匹配，仅选择第一个',
        'term-tap-header-license-file-not-found': '未找到许可证文件名',
        'term-tap-header-name-not-found': '未找到项目名称',
        'term-tap-https-only': '仅支持『https://』ＵＲＬ方案',
        'term-tap-identical-author': '作者和维护者是同一个',
        'term-tap-identical-email': '一个或多个作者电子邮件和维护者电子邮件相同',
        'term-tap-invalid-ci-provider': '『--ci-provider '
                                        '$ciprovider』无法识别。用户将不会被设置',
        'term-tap-leave-blank': '『$key』应为空',
        'term-tap-meson-build-license-array': '在『meson.build』中发现了一个许可证数组，ＯＺＩ只会使用第一个。',
        'term-tap-name-gt32': '名称＞３２个字符',
        'term-tap-netloc': '网络位置',
        'term-tap-not-set': '『$key』未设置',
        'term-tap-summary-gt512': '＞５１２个字符限制',
        'term-tap-target-not-empty': '该目录不为空，不会创建任何文件',
        'term-tap-unsupported-url-scheme': '不支持ＵＲＬ方案',
        'term-tap-up-to-date': 'ＯＺＩ软件包已更新',
        'term-tap-url-scheme': 'ＵＲＬ方案',
        'term-tap-user-template-not-found': '未找到用户模板',
        'term-tox-e-dist': '运行分发和打包',
        'term-tox-e-lint': '运行格式化、静态分析和类型检查',
        'term-tox-e-test': '运行测试和覆盖率',
        'term-warn-remove-dir': '无法删除非空或不存在的$key：『$child』'}}



"""
This type stub file was generated by pyright.
"""

from __future__ import annotations

import shlex
import sys
import termios
import tty
from argparse import Namespace
from typing import TYPE_CHECKING
from typing import Callable
from typing import TypeAlias
from unittest.mock import Mock

from ozi_spec import METADATA
from ozi_templates import load_environment
from tap_producer import TAP

from ozi_core.new.interactive import interactive_prompt
from ozi_core.new.parser import parser
from ozi_core.new.validate import postprocess_arguments
from ozi_core.new.validate import preprocess_arguments
from ozi_core.render import RenderedContent

"""ozi-new: quick-start OZI project creation script."""
if sys.platform != 'win32':
    ...  # import curses
else:
    ...

def project(project: Namespace) -> None:
    """Create a new project in a target directory."""
    ...

def wrap(project: Namespace) -> None:
    """Create a new wrap file for publishing. Not a public function."""
    ...

def main(args: list[str] | None = ...) -> None:
    """Main ozi.new entrypoint."""
    ...

